@@ -18,6 +18,7 @@ class Tanagra_Parser:
             None
         '''
         self.root = None
+        #self.orig_labels = {}
 
     def __next_tag(self, s, i):
         ''' Parameters
@@ -55,8 +56,26 @@ class Tanagra_Parser:
             None: prints tree to terminal
         '''
         self.root.print_tree()
+
+    def set_orig_labels(self, d, u):
+        ''' Parameters
+            ----------
+            self: tanagra parser object
+            d: tree as dict with unique labels
+            u: dict of labels to update
+
+            Returns
+            -------
+            tree as dict with original labels
+        '''
+        for k, v in d.items():
+            if type(v) is dict:
+                self.set_orig_labels(v, u)
+            elif k == "attr":
+                d[k] = u[v]
+        return d
     
-    def make_dict(self):
+    def make_dict(self, unique_values=False):
         ''' Parameters
             ----------
             self: tanagra parser object
@@ -65,7 +84,11 @@ class Tanagra_Parser:
             -------
             tree as dict
         '''
-        return self.root.to_dict(self.root.traverse(self.root))
+        d = self.root.to_dict(self.root.traverse(self.root))
+        if unique_values is False:
+            d = self.set_orig_labels(d, self.orig_labels)
+        
+        return d
 
     def get_node(self, attr):
         ''' Parameters
@@ -185,6 +208,7 @@ class Tanagra_Parser:
                         else:
                             self.root.insert(parents_ops["parent"], parents_ops["op"], attr, op, value)
                     parents_ops = {"parent": attr, "op": op}
+                    #self.orig_labels[attr] = ss
 
                     # insert terminal nodes
                     if "then" in s:
@@ -193,6 +217,9 @@ class Tanagra_Parser:
                             target = s[s.find("target = ") + len("target = "):].replace(" ", "")
                         else:
                             target = s[s.find("class = ") + len("class = "):].replace(" ", "")
+
+                        # store original name
+                        t = target
                         
                         # target values should be unique
                         post_fix = 0
@@ -207,7 +234,8 @@ class Tanagra_Parser:
                             self.root.insert(attr, op, target, None, None)
                         else:
                             self.root.insert(attr, op, target, None, None) 
-                        parents_ops = {}            
+                        parents_ops = {}
+                        #self.orig_labels[target] = t         
                 else:
                     # </UL> encountered, so
                     # go up a tree level
